$VAR1 = [
         {
          'text'    => 'Web',
          'subtree' => [
                        {
                         'href'    => 'http://lindnerei.sourceforge.net/',
                         'text'    => 'MySQL::Admin',
                         'subtree' => [],
                         'target'  => '_blank',
                         'id'      => 'a2',
                         'rid'     => 2
                        },
                        {
                         'rid'     => 3,
                         'text'    => 'lze@perlmonks',
                         'subtree' => [],
                         'href'    => 'http://www.perlmonks.org/?node_id=1135188',
                         'target'  => '_blank',
                         'id'      => 'a3'
                        }
                       ],
          'id'  => 'a1',
          'rid' => 1
         },
         {
          'subtree' => [
                        {
                         'rid'     => 5,
                         'subtree' => [],
                         'href'    => 'http://stackoverflow.com/questions/tagged/perl',
                         'text'    => 'Newest &#39;perl&#39; Questions - Stack Overflow',
                         'target'  => '_blank',
                         'id'      => 'a5'
                        },
                        {
                         'href'    => 'https://wiki.python.org/moin/PerlPhrasebook',
                         'text'    => 'PerlPhrasebook - Python Wiki',
                         'subtree' => [],
                         'target'  => '_blank',
                         'id'      => 'a6',
                         'rid'     => 6
                        },
                        {
                         'target'  => '_blank',
                         'id'      => 'a7',
                         'href'    => 'http://billhails.net/Book/front.html',
                         'subtree' => [],
                         'text'    => 'Exploring Programming Language Architecture in Perl',
                         'rid'     => 7
                        }
                       ],
          'text' => 'Perl',
          'id'   => 'a4',
          'rid'  => 4
         },
         {
          'id'      => 'a8',
          'subtree' => [],
          'text'    => 'it-news',
          'rid'     => 8
         }
        ];
@TreeView = $VAR1;
